@@ -28,11 +28,11 @@
 #ifdef __FreeBSD__
     #include <osreldate.h>
 #endif
-#include "ifo_types.h"
-#include "dvd_reader.h"
-#include "ifo_read.h"
-#include "nav_read.h"
-#include "nav_types.h"
+#include <dvdread/ifo_types.h>
+#include <dvdread/dvd_reader.h>
+#include <dvdread/ifo_read.h>
+#include <dvdread/nav_read.h>
+#include <dvdread/nav_types.h>
 
 #include <tqobject.h>
 #include <tqobjectlist.h>
