@@ -444,11 +444,11 @@ void k9DVDAuthor::author() {
         TQString c("dvdauthor");
         proc=progress->getProcess();//  new TQProcess(c,0);
         *proc << c << "-x" <<  m_xml->name();  //locateLocal("tmp", "k9copy/k9author.xml");
-        connect( proc, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)),
-                 this, TQT_SLOT(DVDAuthorStderr(TDEProcess *, char *, int )) );
-        connect( proc, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int )),
-                 this, TQT_SLOT(DVDAuthorStdout(TDEProcess *, char *, int)) );
-        //    connect(progress, TQT_SIGNAL(cancelled()), this, TQT_SLOT(stopProcess()));
+        connect( proc, TQ_SIGNAL(receivedStderr(TDEProcess *, char *, int)),
+                 this, TQ_SLOT(DVDAuthorStderr(TDEProcess *, char *, int )) );
+        connect( proc, TQ_SIGNAL(receivedStdout(TDEProcess *, char *, int )),
+                 this, TQ_SLOT(DVDAuthorStdout(TDEProcess *, char *, int)) );
+        //    connect(progress, TQ_SIGNAL(cancelled()), this, TQ_SLOT(stopProcess()));
 
         m_copied=0;
         m_lastPos=0;
