@@ -46,7 +46,7 @@ k9MP4Enc::k9MP4Enc ( TQObject *parent, const char *name,const TQStringList& )
 	m_lstVideo=config.getCodecVideo();
 
 	timer = new TQTimer ( this );
-	connect ( timer, TQT_SIGNAL ( timeout() ), this, TQT_SLOT ( timerDone() ) );
+	connect ( timer, TQ_SIGNAL ( timeout() ), this, TQ_SLOT ( timerDone() ) );
 	m_progress=new k9MP4Dlg ( tqApp->mainWidget(),0 );
 
 }
@@ -395,10 +395,10 @@ void k9MP4Enc::execute ( k9DVDTitle *_title )
 			tqDebug ( "%s", s.ascii() );
 			time->start();
 			m_timer3.start();
-			connect ( m_process, TQT_SIGNAL ( receivedStdout ( TDEProcess *, char *, int ) ),this, TQT_SLOT ( getStdout ( TDEProcess *, char *, int ) ) );
-			connect ( m_process, TQT_SIGNAL ( receivedStderr ( TDEProcess *, char *, int ) ),this, TQT_SLOT ( getStderr ( TDEProcess *, char *, int ) ) );
-			//connect(m_process, TQT_SIGNAL(processExited(TDEProcess*)),this,TQT_SLOT(exited(TDEProcess*)));
-			connect ( m_progress,TQT_SIGNAL ( sigCancel() ),this,TQT_SLOT ( slotCancel() ) );
+			connect ( m_process, TQ_SIGNAL ( receivedStdout ( TDEProcess *, char *, int ) ),this, TQ_SLOT ( getStdout ( TDEProcess *, char *, int ) ) );
+			connect ( m_process, TQ_SIGNAL ( receivedStderr ( TDEProcess *, char *, int ) ),this, TQ_SLOT ( getStderr ( TDEProcess *, char *, int ) ) );
+			//connect(m_process, TQ_SIGNAL(processExited(TDEProcess*)),this,TQ_SLOT(exited(TDEProcess*)));
+			connect ( m_progress,TQ_SIGNAL ( sigCancel() ),this,TQ_SLOT ( slotCancel() ) );
 			m_canceled=false;
 			m_progress->show();
 			m_process->start ( TDEProcess::OwnGroup, TDEProcess::All );
