@@ -102,7 +102,7 @@ k9Main::k9Main(TQWidget* parent, const char* name, k9CdDrives *_drives)
   }
   */
 
-  dvd=new k9DVD(TQT_TQOBJECT(this));
+  dvd=new k9DVD(this);
 
   updating=false;
 
@@ -110,15 +110,15 @@ k9Main::k9Main(TQWidget* parent, const char* name, k9CdDrives *_drives)
   listView1->setDefaultRenameAction(TQListView::Accept);
   //    TDEStandardDirs kd;
   m_prefOutput=locateLocal("tmp","k9copy/",true); //kd.findResource("tmp","");
-  connect(drives,TQT_SIGNAL(deviceAdded( k9CdDrive*)),this,TQT_SLOT(deviceAdded( k9CdDrive* )));
-  connect(drives,TQT_SIGNAL(deviceRemoved( k9CdDrive*)),this,TQT_SLOT(deviceRemoved( k9CdDrive* )));
+  connect(drives,TQ_SIGNAL(deviceAdded( k9CdDrive*)),this,TQ_SLOT(deviceAdded( k9CdDrive* )));
+  connect(drives,TQ_SIGNAL(deviceRemoved( k9CdDrive*)),this,TQ_SLOT(deviceRemoved( k9CdDrive* )));
 
   readSettings();
   bInputOpen->setPixmap(SmallIcon("document-open"));
   bInputOpenDir->setPixmap(SmallIcon("folder_open"));
   emit SelectionChanged(NULL,true);
-  m_update=new k9UpdateFactor(TQT_TQOBJECT(this),"");
-  connect(m_update,TQT_SIGNAL(updateFactor_internal()),this,TQT_SLOT(updateFactor_internal()));  
+  m_update=new k9UpdateFactor(this,"");
+  connect(m_update,TQ_SIGNAL(updateFactor_internal()),this,TQ_SLOT(updateFactor_internal()));  
 }
 
 
@@ -532,9 +532,9 @@ void k9Main::Open()
   k9DVDTitle * l_track;
   TQString t;
   TQTime h;
-  connect(listView1,TQT_SIGNAL(itemRenamed(TQListViewItem*,int)),this,TQT_SLOT(itemRenamed(TQListViewItem *,int)));
-  connect(listView1,TQT_SIGNAL(expanded( TQListViewItem*)),this,TQT_SLOT(expanded( TQListViewItem* )));
-  connect(listView1,TQT_SIGNAL(collapsed( TQListViewItem*)),this,TQT_SLOT(collapsed( TQListViewItem* )));
+  connect(listView1,TQ_SIGNAL(itemRenamed(TQListViewItem*,int)),this,TQ_SLOT(itemRenamed(TQListViewItem *,int)));
+  connect(listView1,TQ_SIGNAL(expanded( TQListViewItem*)),this,TQ_SLOT(expanded( TQListViewItem* )));
+  connect(listView1,TQ_SIGNAL(collapsed( TQListViewItem*)),this,TQ_SLOT(collapsed( TQListViewItem* )));
 
   closeDVD();
   TQString sDevice=getDevice(cbInputDev);
@@ -594,7 +594,7 @@ void k9Main::Open()
 void k9Main::setDVDSize()
 {
   //k9DVDSize *dvdsize=static_cast<k9DVDSize  *>(m_factory->create(this,"dvd", "k9DVDSize"));
-  k9DVDSize *dvdsize=new k9DVDSize(TQT_TQOBJECT(this));
+  k9DVDSize *dvdsize=new k9DVDSize(this);
   dvdsize->setMaxSizeDyn(m_prefSize);
   delete dvdsize;
 }
@@ -1414,8 +1414,8 @@ long k9Main::getFreeSpace(const TQString & _path)
   KDiskFreeSp *FreeSp=new KDiskFreeSp();
   ;
 
-  connect(FreeSp,TQT_SIGNAL(foundMountPoint (const TQString &, unsigned long , unsigned long , unsigned long )),this,TQT_SLOT(foundMountPoint (const TQString &, unsigned long , unsigned long , unsigned long )));
-  connect(FreeSp,TQT_SIGNAL(done ( )),this,TQT_SLOT(fspDone ()));
+  connect(FreeSp,TQ_SIGNAL(foundMountPoint (const TQString &, unsigned long , unsigned long , unsigned long )),this,TQ_SLOT(foundMountPoint (const TQString &, unsigned long , unsigned long , unsigned long )));
+  connect(FreeSp,TQ_SIGNAL(done ( )),this,TQ_SLOT(fspDone ()));
   TQString mountPoint = TDEIO::findPathMountPoint( _path );
   FreeSp->readDF(mountPoint);
   do
